# Generated by roxygen2: do not edit by hand

S3method("$",RDecoder)
S3method("$",RDecoderByteLevel)
S3method("$",REncoding)
S3method("$",RModel)
S3method("$",RModelBPE)
S3method("$",RModelUnigram)
S3method("$",RModelWordPiece)
S3method("$",RNormalizer)
S3method("$",RNormalizerNFC)
S3method("$",RNormalizerNFKC)
S3method("$",RPostProcessor)
S3method("$",RPostProcessorByteLevel)
S3method("$",RPreTokenizer)
S3method("$",RPreTokenizerByteLevel)
S3method("$",RPreTokenizerWhitespace)
S3method("$",RTokenizer)
S3method("$",RTrainer)
S3method("$",RTrainerBPE)
S3method("$",RTrainerUnigram)
S3method("$",RTrainerWordPiece)
S3method("[[",RDecoder)
S3method("[[",RDecoderByteLevel)
S3method("[[",REncoding)
S3method("[[",RModel)
S3method("[[",RModelBPE)
S3method("[[",RModelUnigram)
S3method("[[",RModelWordPiece)
S3method("[[",RNormalizer)
S3method("[[",RNormalizerNFC)
S3method("[[",RNormalizerNFKC)
S3method("[[",RPostProcessor)
S3method("[[",RPostProcessorByteLevel)
S3method("[[",RPreTokenizer)
S3method("[[",RPreTokenizerByteLevel)
S3method("[[",RPreTokenizerWhitespace)
S3method("[[",RTokenizer)
S3method("[[",RTrainer)
S3method("[[",RTrainerBPE)
S3method("[[",RTrainerUnigram)
S3method("[[",RTrainerWordPiece)
export(decoder_byte_level)
export(encoding)
export(model_bpe)
export(model_unigram)
export(model_wordpiece)
export(normalizer_nfc)
export(normalizer_nfkc)
export(pre_tokenizer)
export(pre_tokenizer_byte_level)
export(pre_tokenizer_whitespace)
export(processor_byte_level)
export(tok_decoder)
export(tok_model)
export(tok_normalizer)
export(tok_processor)
export(tok_trainer)
export(tokenizer)
export(trainer_bpe)
export(trainer_unigram)
export(trainer_wordpiece)
importFrom(R6,R6Class)
importFrom(cli,cli_abort)
useDynLib(tok, .registration = TRUE)
